![DHLLinAlg Logo](https://raw.githubusercontent.com/DHL-ASC/DHL-LinAlg/main/img/dhl-linalg-banner.png)

![Build Status](https://github.com/shirnschall/dhl-linalg/actions/workflows/ci-pip.yml/badge.svg)
[![Documentation Status](https://readthedocs.org/projects/dhl-linalg/badge/?version=latest)](https://dhl-linalg.readthedocs.io/en/latest/?badge=latest)

--------------------------------------------------------------------------------


DHL-LinAlg is a simple linear algebra implementation using modern C++.     
     
This library is part of a scientific programing course at TU Vienna. Here are notes on the
[development process](https://jschoeberl.github.io/IntroSC/intro.html).


## Installation
  
``` bash
pip install dhllinalg
```

### Building from sorce:

#### Requirements
pybind11, cmake, scikit-build

```bash
git clone --recurse-submodules https://github.com/DHL-ASC/DHL-LinAlg.git 
cd DHL-LinAlg  
pip install .
```


